==> estateplat-common-1.2.3-20180408.075516-60-sources.jar: cn/gtmap/estateplat/model/commodityHouse/contract/FcjyXjspfMmhtFwfsss.java <==
package cn.gtmap.estateplat.model.commodityHouse.contract;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:lizhi@gtmap.cn ">lizhi</a>
 * @version 1.0, 2018/2/24
 * @description      商品房买卖合同房屋附属设施表
 */
@Table(name = "fcjy_xjspf_mmht_fwfsss")
public class FcjyXjspfMmhtFwfsss {
    @Id
    private String fwfsssid;//主键
    private String hid;//户id
    private String htid;//合同ID
    private String zh;//幢号
    private String fh;//房号
    private String cc;//层次
    private String yt;//用途
    private String jg;//结构
    private Double cg;//层高（M）
    private Double jzmj;//建筑面积
    private Double tnmj;//套内面积
    private Double ftmj;//分摊面积
    private String jjfs;//计价方式
    private Double dj;//单价
    private String dw;//单位
    private Double zj;//总价

    public String getFwfsssid() {
        return fwfsssid;
    }

    public void setFwfsssid(String fwfsssid) {
        this.fwfsssid = fwfsssid;
    }

    public String getHtid() {
        return htid;
    }

    public void setHtid(String htid) {
        this.htid = htid;
    }

    public String getZh() {
        return zh;
    }

    public void setZh(String zh) {
        this.zh = zh;
    }

    public String getFh() {
        return fh;
    }

    public void setFh(String fh) {
        this.fh = fh;
    }

    public String getCc() {
        return cc;
    }

    public void setCc(String cc) {
        this.cc = cc;
    }

    public String getYt() {
        return yt;
    }

    public void setYt(String yt) {
        this.yt = yt;
    }

    public String getJg() {
        return jg;
    }

    public void setJg(String jg) {
        this.jg = jg;
    }

    public Double getCg() {
        return cg;
    }

    public void setCg(Double cg) {
        this.cg = cg;
    }

    public Double getJzmj() {
        return jzmj;
    }

    public void setJzmj(Double jzmj) {
        this.jzmj = jzmj;
    }

    public Double getTnmj() {
        return tnmj;
    }

    public void setTnmj(Double tnmj) {
        this.tnmj = tnmj;
    }

    public Double getFtmj() {
        return ftmj;
    }

    public void setFtmj(Double ftmj) {
        this.ftmj = ftmj;
    }

    public String getJjfs() {
        return jjfs;
    }

    public void setJjfs(String jjfs) {
        this.jjfs = jjfs;
    }

    public Double getDj() {
        return dj;
    }

    public void setDj(Double dj) {
        this.dj = dj;
    }

    public String getDw() {
        return dw;
    }

    public void setDw(String dw) {
        this.dw = dw;
    }

    public Double getZj() {
        return zj;
    }

    public void setZj(Double zj) {
        this.zj = zj;
    }

    public String getHid() {
        return hid;
    }

    public void setHid(String hid) {
        this.hid = hid;
    }
}

==> estateplat-common-1.2.3-20180705.065655-137-sources.jar: cn/gtmap/estateplat/model/commodityHouse/contract/FcjyXjspfMmhtFwfsss.java <==
package cn.gtmap.estateplat.model.commodityHouse.contract;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
 * @author <a href="mailto:lizhi@gtmap.cn ">lizhi</a>
 * @version 1.0, 2018/2/24
 * @description      商品房买卖合同房屋附属设施表
 */
@Table(name = "fcjy_xjspf_mmht_fwfsss")
public class FcjyXjspfMmhtFwfsss implements Serializable {
    @Id
    private String fwfsssid;//主键
    private String hid;//户id
    private String htid;//合同ID
    private String zh;//幢号
    private String fh;//房号
    private String cc;//层次
    private String yt;//用途
    private String jg;//结构
    private Double cg;//层高（M）
    private Double jzmj;//建筑面积
    private Double tnmj;//套内面积
    private Double ftmj;//分摊面积
    private String jjfs;//计价方式
    private Double dj;//单价
    private String dw;//单位
    private Double zj;//总价

    public String getFwfsssid() {
        return fwfsssid;
    }

    public void setFwfsssid(String fwfsssid) {
        this.fwfsssid = fwfsssid;
    }

    public String getHtid() {
        return htid;
    }

    public void setHtid(String htid) {
        this.htid = htid;
    }

    public String getZh() {
        return zh;
    }

    public void setZh(String zh) {
        this.zh = zh;
    }

    public String getFh() {
        return fh;
    }

    public void setFh(String fh) {
        this.fh = fh;
    }

    public String getCc() {
        return cc;
    }

    public void setCc(String cc) {
        this.cc = cc;
    }

    public String getYt() {
        return yt;
    }

    public void setYt(String yt) {
        this.yt = yt;
    }

    public String getJg() {
        return jg;
    }

    public void setJg(String jg) {
        this.jg = jg;
    }

    public Double getCg() {
        return cg;
    }

    public void setCg(Double cg) {
        this.cg = cg;
    }

    public Double getJzmj() {
        return jzmj;
    }

    public void setJzmj(Double jzmj) {
        this.jzmj = jzmj;
    }

    public Double getTnmj() {
        return tnmj;
    }

    public void setTnmj(Double tnmj) {
        this.tnmj = tnmj;
    }

    public Double getFtmj() {
        return ftmj;
    }

    public void setFtmj(Double ftmj) {
        this.ftmj = ftmj;
    }

    public String getJjfs() {
        return jjfs;
    }

    public void setJjfs(String jjfs) {
        this.jjfs = jjfs;
    }

    public Double getDj() {
        return dj;
    }

    public void setDj(Double dj) {
        this.dj = dj;
    }

    public String getDw() {
        return dw;
    }

    public void setDw(String dw) {
        this.dw = dw;
    }

    public Double getZj() {
        return zj;
    }

    public void setZj(Double zj) {
        this.zj = zj;
    }

    public String getHid() {
        return hid;
    }

    public void setHid(String hid) {
        this.hid = hid;
    }
}
